# Thank You
Python module to print "Thanks/Thank you" in every known language.
Install it, import it and use it with
```python
from thankyou import give_thanks
thanks = give_thanks()
```

So, why do this?
Why not I may reply.

It's just a "nicer" way to generate random (sometimes hostile) data.

[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/mariofix/thankyou/main.svg)](https://results.pre-commit.ci/latest/github/mariofix/thankyou/main) [![Thank You](https://github.com/mariofix/thankyou/actions/workflows/tests.yml/badge.svg)](https://github.com/mariofix/thankyou/actions/workflows/tests.yml) [![PyPI version](https://badge.fury.io/py/thankyou.svg)](https://badge.fury.io/py/thankyou) [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
